netapp_ontap.resources.barbican API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.barbican`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

Barbican Key Management Services (KMS) is a key management service that provides a secure store for encryption keys. This feature allows ONTAP to securely protect its encryption keys using Barbican KMS. Before you can use Barbican KMS with ONTAP, you must provide ONTAP with the necessary details to allow ONTAP to communicate with the deployed Barbican application. These details include the key ID URL, Keystone authentication URL, and the application credentials ID and secret. The property `barbican_reachability` is considered an advanced property and is populated only when explicitly requested.

## Examples

### Creating an inactive Barbican configuration for an SVM

The example Barbican configuration is created for a specific SVM but is not enabled. Note the return_records=true query parameter can be used to return the newly created key-manager keystore configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Barbican

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Barbican()
        resource.svm = {"name": "barbican_svm"}
        resource.configuration = {"name": "myConfiguration"}
        resource.application_cred_id = "app1"
        resource.application_cred_secret = "secret1"
        resource.key_id = (
            "https://sample.keyid.com:9311/v1/secrets/5c610a4f-ea97-44b5-8682-f4daeafa9647/"
        )
        resource.keystone_url = "https://sample.keystone.com:5000/v3/auth/tokens"
        resource.post(hydrate=True)
        print(resource)

Try it out

    Barbican(
        {
            "configuration": {"name": "myConfiguration"},
            "application_cred_secret": "secret1",
            "keystone_url": "https://sample.keystone.com:5000/v3/auth/tokens",
            "application_cred_id": "app1",
            "key_id": "https://sample.keyid.com:9311/v1/secrets/5c610a4f-ea97-44b5-8682-f4daeafa9647/",
            "svm": {"name": "barbican_svm"},
        }
    )

### Listing all Barbican configurations

The following example shows how to retrieve a list of all created Barbican configurations.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Barbican

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(Barbican.get_collection()))

Try it out

    [
        Barbican(
            {
                "configuration": {
                    "name": "myConfiguration",
                    "uuid": "5a134975-fa58-11ef-8c9f-005056bbeee5",
                },
                "_links": {
                    "self": {
                        "href": "/api/security/barbican-kms/5a134975-fa58-11ef-8c9f-005056bbeee5"
                    }
                },
                "uuid": "5a134975-fa58-11ef-8c9f-005056bbeee5",
            }
        )
    ]

### Retrieving a specific Barbican configuration

The following example shows how to retrieve information for a specific Barbican configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Barbican

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Barbican(uuid="5a134975-fa58-11ef-8c9f-005056bbeee5")
        resource.get(fields="*")
        print(resource)

Try it out

    Barbican(
        {
            "configuration": {
                "name": "myConfiguration",
                "uuid": "5a134975-fa58-11ef-8c9f-005056bbeee5",
            },
            "timeout": 10,
            "verify_host": True,
            "proxy_host": "",
            "keystone_url": "https://sample.keystone.com:5000/v3/auth/tokens",
            "verify": True,
            "enabled": False,
            "proxy_username": "",
            "_links": {
                "self": {
                    "href": "/api/security/barbican-kms/5a134975-fa58-11ef-8c9f-005056bbeee5"
                }
            },
            "application_cred_id": "app1",
            "key_id": "https://sample.keyid.com:9311/v1/secrets/5c610a4f-ea97-44b5-8682-f4daeafa9647/",
            "proxy_type": "https",
            "uuid": "5a134975-fa58-11ef-8c9f-005056bbeee5",
            "proxy_port": 0,
            "scope": "svm",
            "svm": {"name": "barbican_svm", "uuid": "ec8e0954-fa10-11ef-8c9f-005056bbeee5"},
        }
    )

### Retrieving an advanced property for a specific Barbican configuration

The following example shows how to retrieve an advanced property for a specific Barbican configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Barbican

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Barbican(uuid="f72098a2-e908-11ea-bd56-005056bb4222")
        resource.get(fields="barbican_reachability")
        print(resource)

Try it out

    Barbican(
        {
            "configuration": {
                "name": "myConfiguration",
                "uuid": "f72098a2-e908-11ea-bd56-005056bb4222",
            },
            "_links": {
                "self": {
                    "href": "/api/security/barbican-kms/f72098a2-e908-11ea-bd56-005056bb4222"
                }
            },
            "uuid": "f72098a2-e908-11ea-bd56-005056bb4222",
            "barbican_reachability": {"message": "", "code": "0", "reachable": True},
        }
    )

### Updating the application credentials ID and secret for a specific Barbican configuration

The following example shows how to update the application credentials for a specific Barbican configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Barbican

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Barbican(uuid="f72098a2-e908-11ea-bd56-005056bb4222")
        resource.application_cred_id = "app345"
        resource.application_cred_secret = "secret"
        resource.patch()

### Enabling a Barbican configuration

The newly created Barbican configuration is inactive by default. Use the REST API PATCH method "/api/security/key-stores/{uuid}" to enable the configuration.

### Restoring keys

The following example shows how to restore keys for a specific Barbican configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Barbican

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Barbican(uuid="f72098a2-e908-11ea-bd56-005056bb4222")
        resource.restore()

Try it out

    Barbican({})

### Rekey the internal key

The following example shows how to rekey the internal key based on a specific Barbican configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Barbican

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Barbican(uuid="f72098a2-e908-11ea-bd56-005056bb4222")
        resource.rekey_internal()

Try it out

    Barbican({})

## Classes

`class Barbican (*args, **kwargs)`

  Allows interaction with Barbican objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection (*args, connection: HostConnection = None, **kwargs) -> int`

    Returns a count of all Barbican resources that match the provided query

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def fast_get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[RawResource]`

    Returns a list of RawResources that represent Barbican resources that match the provided query

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def find (*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves Barbican KMS configurations for all SVMs.

    ### Related ONTAP commands

    - `security key-manager external barbican show`
    - `security key-manager external barbican check`

    ### Learn more

    - `DOC /security/barbican-kms`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[Resource]`

    Retrieves Barbican KMS configurations for all SVMs.

    ### Related ONTAP commands

    - `security key-manager external barbican show`
    - `security key-manager external barbican check`

    ### Learn more

    - `DOC /security/barbican-kms`

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection (body: dict, *args, records: Iterable[ForwardRef('Barbican')] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates the Barbican KMS configuration.

    ### Optional properties

    - `application_cred_id` - New credentials used to verify the application's identity to the Barbican KMS. You must provide both `application_cred_id` and `application_cred_secret` to update the credentials.
    - `application_cred_secret` - New credentials secret used to verify the application's identity to the Barbican KMS. You must provide both `application_cred_id` and `application_cred_secret` to update the credentials.
    - `proxy_type` - Type of proxy (http/https) if proxy configuration is used.
    - `proxy_host` - Proxy hostname if proxy configuration is used.
    - `proxy_port` - Proxy port number if proxy configuration is used.
    - `proxy_username` - Proxy username if proxy configuration is used.
    - `proxy_password` - Proxy password if proxy configuration is used.
    - `verify` - Verify the identity of the Barbican KMS?
    - `verify_host` - Verify the identity of the Barbican KMS host name?
    - `timeout` - Connection timeout in seconds.

    ### Related ONTAP commands

    - `security key-manager external barbican update-credentials`
    - `security key-manager external barbican update-config`

    ### Learn more

    - `DOC /security/barbican-kms`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection. The body argument will be ignored if records is provided.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be patched on the host.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post_collection (records: Iterable[ForwardRef('Barbican')], *args, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> Union[List[Barbican], NetAppResponse]`

    Creates a Barbican KMS configuration for the specified SVM.

    ### Required properties

    - `configuration.name` - Name for the new Barbican configuration.
    - `svm.uuid` or `svm.name` - Existing SVM in which to create a Barbican KMS.
    - `key_id` - Barbican key URL.
    - `keystone_url` - Keystone authentication URL.
    - `application_cred_id` - Keystone authentication application ID with access to the Barbican KMS.
    - `application_cred_secret`- Application credentials secret to authenticate the application credentials ID with Keystone.

    ### Optional properties

    - `proxy_type` - Type of proxy (http/https) if proxy configuration is used.
    - `proxy_host` - Proxy hostname if proxy configuration is used.
    - `proxy_port` - Proxy port number if proxy configuration is used.
    - `proxy_username` - Proxy username if proxy configuration is used.
    - `proxy_password` - Proxy password if proxy configuration is used.
    - `verify` - Verify the identity of the Barbican KMS?
    - `verify_host` - Verify the identity of the Barbican KMS host name?
    - `timeout` - Connection timeout in seconds.

    ### Related ONTAP commands

    - `security key-manager external barbican create-config`

    ### Learn more

    - `DOC /security/barbican-kms`

    Send this collection of objects to the host as a creation request.

    ## Args

    `records`
      A list of `Resource` objects to send to the server to be created.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to create a bar for a particular foo, the foo.name value should be passed.
    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of each object. When hydrate is set to True, poll must also be set to True.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A list of `Resource` objects matching the provided type which have been created by the host and returned. This is not the same list that was provided, so to continue using the object, you should save this list. If poll is set to False, then a `NetAppResponse` object is returned instead.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves the Barbican KMS configuration for the SVM specified by the UUID.

    ### Related ONTAP commands

    - `security key-manager external barbican show`
    - `security key-manager external barbican check`

    ### Learn more

    - `DOC /security/barbican-kms`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Updates the Barbican KMS configuration.

    ### Optional properties

    - `application_cred_id` - New credentials used to verify the application's identity to the Barbican KMS. You must provide both `application_cred_id` and `application_cred_secret` to update the credentials.
    - `application_cred_secret` - New credentials secret used to verify the application's identity to the Barbican KMS. You must provide both `application_cred_id` and `application_cred_secret` to update the credentials.
    - `proxy_type` - Type of proxy (http/https) if proxy configuration is used.
    - `proxy_host` - Proxy hostname if proxy configuration is used.
    - `proxy_port` - Proxy port number if proxy configuration is used.
    - `proxy_username` - Proxy username if proxy configuration is used.
    - `proxy_password` - Proxy password if proxy configuration is used.
    - `verify` - Verify the identity of the Barbican KMS?
    - `verify_host` - Verify the identity of the Barbican KMS host name?
    - `timeout` - Connection timeout in seconds.

    ### Related ONTAP commands

    - `security key-manager external barbican update-credentials`
    - `security key-manager external barbican update-config`

    ### Learn more

    - `DOC /security/barbican-kms`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Creates a Barbican KMS configuration for the specified SVM.

    ### Required properties

    - `configuration.name` - Name for the new Barbican configuration.
    - `svm.uuid` or `svm.name` - Existing SVM in which to create a Barbican KMS.
    - `key_id` - Barbican key URL.
    - `keystone_url` - Keystone authentication URL.
    - `application_cred_id` - Keystone authentication application ID with access to the Barbican KMS.
    - `application_cred_secret`- Application credentials secret to authenticate the application credentials ID with Keystone.

    ### Optional properties

    - `proxy_type` - Type of proxy (http/https) if proxy configuration is used.
    - `proxy_host` - Proxy hostname if proxy configuration is used.
    - `proxy_port` - Proxy port number if proxy configuration is used.
    - `proxy_username` - Proxy username if proxy configuration is used.
    - `proxy_password` - Proxy password if proxy configuration is used.
    - `verify` - Verify the identity of the Barbican KMS?
    - `verify_host` - Verify the identity of the Barbican KMS host name?
    - `timeout` - Connection timeout in seconds.

    ### Related ONTAP commands

    - `security key-manager external barbican create-config`

    ### Learn more

    - `DOC /security/barbican-kms`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def rekey_internal (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Rekeys the internal key in the key hierarchy for an SVM with a Barbican KMS configuration.

    ### Related ONTAP commands

    - `security key-manager external barbican rekey-internal`

    Perform a custom action on this resource which is not a simple CRUD action

    ## Args

    `path`
      The action verb for this request. This will be added as a postfix to the instance location of the resource.
    `body`
      The body of the action request. This should be a Resource instance. The connection and URL will be determined based on the values from this object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def restore (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Restores the keys for an SVM from a configured Barbican KMS.

    ### Related ONTAP commands

    - `security key-manager external barbican restore`

    Perform a custom action on this resource which is not a simple CRUD action

    ## Args

    `path`
      The action verb for this request. This will be added as a postfix to the instance location of the resource.
    `body`
      The body of the action request. This should be a Resource instance. The connection and URL will be determined based on the values from this object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class BarbicanSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the Barbican object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `application_cred_id: str GET POST PATCH`

    Keystone application credentials ID required to access the specified Barbican KMS.

    Example: 63e3cb77f84f42b7a0395a3efb7636f9

  `application_cred_secret: str POST PATCH`

    Keystone application credentials secret required to access the specified Barbican KMS. It is not audited.

    Example: secret

  `barbican_reachability: BarbicanConnectivity GET`

    Indicates whether the Barbican KMS is reachable from all nodes in the cluster. This is an advanced property; there is an added computational cost to retrieving its value. The property is not populated for either a collection GET request or an instance GET request unless it is explicitly requested using the field's query parameter or GET for all advanced properties is enabled.

  `configuration: SecurityKeystoreConfiguration GET POST`

    Security keystore object reference.

  `enabled: bool GET`

    Indicates whether the configuration is enabled.

  `key_id: str GET POST`

    Key Identifier URL of the Barbican KMS key encryption key. Must be an HTTPS URL.

    Example: https://172.29.58.184:9311/v1/secrets/5c610a4f-ea97-44b5-8682-f4daeafa9647

  `keystone_url: str GET POST`

    Keystone URL for the access token. Must be an HTTPS URL.

    Example: https://keystoneip:5000/v3/auth/tokens

  `links: SelfLink GET`

    The links field of the barbican.

  `proxy_host: str GET POST PATCH`

    Proxy host name.

    Example: proxy.eng.com

  `proxy_password: str POST PATCH`

    Proxy password. Password is not audited.

    Example: proxypassword

  `proxy_port: Size GET POST PATCH`

    Proxy port number.

    Example: 1234

  `proxy_type: str GET POST PATCH`

    Type of proxy.

    Valid choices:

    - http
    - https
  `proxy_username: str GET POST PATCH`

    Proxy username.

    Example: proxyuser

  `scope: str GET`

    Set to "svm" for interfaces owned by an SVM. Otherwise, set to "cluster".

    Valid choices:

    - svm
    - cluster
  `state: BarbicanState GET`

    Indicates whether or not the SVM key encryption key (KEK) is available cluster wide. This is an advanced property; there is an added computational cost to retrieving its value. The property is not populated for either a collection GET or an instance GET unless it is explicitly requested using the `fields` query parameter or GET for all advanced properties is enabled.

  `svm: Svm GET POST`

    The svm field of the barbican.

  `timeout: Size GET POST PATCH`

    Connection timeout in seconds.

    Example: 60

  `uuid: str GET`

    A unique identifier of the Barbican KMS.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563434

  `verify: bool GET POST PATCH`

    Verify the identity of the Barbican KMS.

  `verify_host: bool GET POST PATCH`

    Verify the identity of the Barbican KMS host name.